﻿# -*- coding: utf-8 -*-
"""
Issues an error when there is an input to an invalid item.
"""

import cse
import cseMessageBox


# Method for checking output sheets.
def CheckOutSheet(s, e):
  # Plugin execution event data.
  v = e.Value
  
  # Error Type
  errtype = "ERR_DisablingFilled"
  
  for sti in v.sheets:
    # Only shown checksheets.
    if not sti.IsShown:
      continue
    
    # Loop on content implemented on parent side and child side.
    for contset in cse.getcontssets(sti.Sheet, False):
      # Make a list of disabled cells and treat entries as errors.
      for cont in cse.getdisabledlist(contset):
        if not cont.IsEmpty:
          v.errors.append({'type': errtype, 'path': cse.deparsepath(cont), 'nooutput': True})
    



# Method for checking entry sheets.
def CheckImportedSheet(s, e):
  # Plugin execution event data.
  v = e.Value
  
  # Loop until there are no more entries in disabled cells.
  while True:
    disablingFilledCells = []
    
    # Loop for each SheetTabInfo.
    for sti in v.sheets:
      # Loop on content implemented on parent side and child side.
      for contset in cse.getcontssets(sti.Sheet, False):
        # Make a list of disabled cells and treat entries as errors.
        for cont in cse.getdisabledlist(contset):
          if not cont.IsEmpty:
            disablingFilledCells.append(cont)
    
    # If there are entries in disabled cells and "Yes" has been selected in the dialog box, delete all.
    if len(disablingFilledCells) > 0:
      # Create a dialog box message. (The first 32 elements of the disabled cell.)
      errtargets = "\n".join("  " + cse.getcellpathtitle(str(cont.Path)) for cont in disablingFilledCells[:32])
      errmsg = cse.getapplang("PlgMsg_ChkDsbl_AllClear") % errtargets
      if len(disablingFilledCells) > 32:
        # Display the number that have been omitted.
        errmsg += "\n  and more... (%d)" % (len(disablingFilledCells) - 32)
      
      if cseMessageBox.askyesno("", errmsg):
        for cont in disablingFilledCells:
          cont.Clear()
        # Again
        continue
    
    # If there are no entries in disabled cells and "No" has been selected in the dialog box, then exit the loop.
    break


cse.addhandler("RequestCheckOutSheet", CheckOutSheet)
cse.addhandler("AfterFileImported", CheckImportedSheet)
