﻿# -*- coding: utf-8 -*-
"""
Checks production information consistency.
"""
# Language key for plugin used:
#   PlgErr_ProdInfo_TitleEmpty
#     The title field is empty.
#   PlgErr_ProdInfo_InvalidProdCode
#     The product code is invalid.
#   PlgErr_ProdInfo_InvalidAocCode
#     For add-on content, also enter the variation in the Initial Code field. (In the following format: "****-XX")


import cse
import re

def DoCheckProdInfo(prodinfo, errors):
  # Error Type
  errtype = "ERR_ProdInfoEmpty"
  errmsgttl = "PlgErr_ProdInfo_TitleEmpty"
  errmsgprd = "PlgErr_ProdInfo_InvalidProdCode"
  errmsgaoc = "PlgErr_ProdInfo_InvalidAocCode"
  
  # Title required.
  if prodinfo.Title == None or prodinfo.Title == "":
    errors.append({'type': errtype, 'msg': errmsgttl, 'dlg': 'productsetting'})
  
  
  # The product category code is three characters.
  if re.match(r"^[A-Z0-9]{3}$", prodinfo.ClassCode) == None:
    errors.append({'type': errtype, 'msg': errmsgprd, 'dlg': 'productsetting'})
    return
  
  # The form code is one character.
  if re.match(r"^[A-Z0-9]$", prodinfo.FormCode) == None:
    errors.append({'type': errtype, 'msg': errmsgprd, 'dlg': 'productsetting'})
    return
  
  # Consistency of initial code.
  if (prodinfo.ClassCode == "CTR" or prodinfo.ClassCode == "WUP") and prodinfo.FormCode == "M":
    if re.match(r"^\w{4}-[a-fA-F0-9]{2}$", prodinfo.InitCode) == None:
      # If the form code is 'M,' then initial code + variation is required.
      errors.append({'type': errtype, 'msg': errmsgaoc, 'dlg': 'productsetting'})
      return
  else:
    if re.match(r"^\w{4}$", prodinfo.InitCode) == None:
      # If the form code is not 'M,' then only the initial code.
      errors.append({'type': errtype, 'msg': errmsgprd, 'dlg': 'productsetting'})
      return
  


# Method for checking output sheets.
def CheckOutSheet(s, e):
  # Plugin execution event data.
  v = e.Value
  
  # Runs the check.
  DoCheckProdInfo(v.prodinfo, v.errors)
  


cse.addhandler("RequestCheckOutSheet", CheckOutSheet)

